// MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software,
// and any derivatives created by any person or entity by or on your
// behalf, exclusively with Microchip's products. Microchip and its
// licensors retain all ownership and intellectual property rights in
// the accompanying software and in all derivatives hereto.
//
// This software and any accompanying information is for suggestion
// only. It does not modify Microchip's standard warranty for its
// products. You agree that you are solely responsible for testing the
// software and determining its suitability. Microchip has no obligation
// to modify, test, certify, or support the software.
//
// THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES,
// WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO,
// IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS
// FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
// MICROCHIP'S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN
// ANY APPLICATION.
//
// IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
// TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
// LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
// SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS,
// DAMAGE, FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE
// SOFTWARE, HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE
// POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT
// ALLOWABLE BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY
// WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF
// ANY, THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
//
// MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE
// OF THESE TERMS.

/**
 * @file adc.h
 */

#ifndef __ADC_H_
#define __ADC_H_

#include <stdint.h> // uint8_t, uint16_t, etc typdefs
#include "common.h"

#define ADC_MAX             1023 // ADC bits of resolution
#define IOC_VMIN            1.2 // @todo PIC issues an IOC on this min input voltage
#define ADC_STEP            ((ADC_REF * 1.0)/ADC_MAX)
#define VOLT_TO_ADC(volt)   (volt/ADC_STEP)

// The actual expected ADC reading in a range
#define IOC_ADC             (uint16_t)VOLT_TO_ADC(IOC_VMIN) // Minimum Vadc to cause IOC

#define S1_ADC              (uint16_t)VOLT_TO_ADC((S1_V * 1.0))
#define S2_ADC              (uint16_t)VOLT_TO_ADC((S2_V * 1.0))
// Use the middle voltage to determine what button was pressed
#define S_MID_ADC           (uint16_t)(((S1_ADC - S2_ADC)/ 2.0) + S2_ADC) // **Assumes S1_V > S2_V

#define AUX2_ADC            (uint16_t)VOLT_TO_ADC((AUX2_V * 1.0))
#define AUX3_ADC            (uint16_t)VOLT_TO_ADC((AUX3_V * 1.0))
#define AUX4_ADC            (uint16_t)VOLT_TO_ADC((AUX4_V * 1.0))

// This is the trip voltage expected from the ADC multipled by the AVG # of data points
#define CURRENT_TRIP_ADC     (uint16_t)(VOLT_TO_ADC(CURRENT_TRIP_V) * CURRENT_TRIP_AVG)


extern void SetupADC(void);
extern uint16_t GetSpeed(void);
extern uint16_t GetCurrentPinch(void);
extern uint16_t GetButtons(void);
extern uint16_t GetCurrentSense(void);
extern uint16_t GetAuxInputs(void);


#endif