// MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software,
// and any derivatives created by any person or entity by or on your
// behalf, exclusively with Microchip's products. Microchip and its
// licensors retain all ownership and intellectual property rights in
// the accompanying software and in all derivatives hereto.
//
// This software and any accompanying information is for suggestion
// only. It does not modify Microchip's standard warranty for its
// products. You agree that you are solely responsible for testing the
// software and determining its suitability. Microchip has no obligation
// to modify, test, certify, or support the software.
//
// THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES,
// WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO,
// IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS
// FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
// MICROCHIP'S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN
// ANY APPLICATION.
//
// IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
// TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
// LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
// SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS,
// DAMAGE, FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE
// SOFTWARE, HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE
// POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT
// ALLOWABLE BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY
// WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF
// ANY, THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
//
// MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE
// OF THESE TERMS.


#ifndef __MODULATE_H
#define __MODULATE_H

#include <stdint.h>
#include <stdbool.h>
#include "common.h"
#include "pwm.h"

/**
 * ModVoltage is the Amplitude variable. Amplitude will be 0 when motor is not spinning,
 * otherwise the POT and SoftStart routine will use these min/max values
 *
 * The V/F profile is linear up to MODULATION_IDEAL. From then, the amplitude is always max.
 * Therefore the minimum amplitude must be related in a 1:1 fashion
 *
 *  Range:    0 <= 0 <= 127
 */
#define AMPLITUDE_MAX       127
#define AMPLITUDE_MIN       (uint8_t)(((MODULATION_MIN * 1.0) / MODULATION_IDEAL) * AMPLITUDE_MAX)

#define ADC_STOP_POS            10 // When to stop the modulation
#define ADC_STOP_NEG            -10 // When to stop the modulation

// @see AN984 pg. 5 for more info
#define MOD_RES  ((SET_FREQ * 1.0) / UINT16_MAX) // Hz/bit
#define DELTA_MIN (uint16_t)(MODULATION_MIN / MOD_RES) // Delta Phase value that equates to the min freq
#define DELTA_IDEAL (uint16_t)(MODULATION_IDEAL / MOD_RES) // Delta Phase value that equates to the ideal freq
#define DELTA_MAX (uint16_t)(MODULATION_MAX / MOD_RES) // Delta Phase value that equates to the max freq


// Prototypes
extern void Modulate(uint16_t angle, uint16_t *phase1, uint16_t *phase2, uint16_t *phase3);
extern void LoadModulateBuffer(uint8_t volts);
extern uint8_t CalcAmplitude(uint16_t phase, uint16_t ADCResult);
extern uint16_t CalcPhase(uint16_t ADCResult);

#endif